==> prestashop_1.5.0.5.zip: prestashop/themes/default/pdf/lang/fr.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['submitTranslationsPdf'] = '1';
$_LANGPDF['PDF065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF6c2fbe34c186a6b5725d212ad8cd2432'] = 'Facture';
$_LANGPDF['PDFf771e4a4df40bf061607fdb8e3f140dc'] = 'Bon de commande';
$_LANGPDF['PDF3a80d6ec5285dd5d3930db30d04e2b9e'] = 'HR : hors remise';
$_LANGPDF['PDFa58b1c9575ab07c5be819243c96d9c0e'] = 'RC : remise comprise';
$_LANGPDF['PDF2f2f0f119a907c6c67a3c6fcde0193ab'] = 'Addresse de Livraison';
$_LANGPDF['PDF28a59051cd90053f87bacd5f1ffbc0b8'] = 'Adresse de Paiement';
$_LANGPDF['PDFe2f324b87eac820c81e4d4a1105dcddf'] = 'Adresse de Paiement & Livraison';
$_LANGPDF['PDFd8b2145d049378e78bd41e65b31213f0'] = 'Num. commande :';
$_LANGPDF['PDF8a5a12ba783d8cbb761974430d0a4d6a'] = 'Date commande :';
$_LANGPDF['PDFd36a6948b01d3a75ed99858e2bfea939'] = 'Méthode de paiement :';
$_LANGPDF['PDFe40007b408ac5f66d2c2e6c54f787c99'] = 'Aucun paiement';
$_LANGPDF['PDF24488494b2a9126a5ef1dfdaea5913da'] = 'Produits à retourner';
$_LANGPDF['PDFdcd320d017d7f3c317bc8b234287bc9f'] = 'Réference';
$_LANGPDF['PDFe36ba4b339b83cbb3c807bd0eb5610bc'] = 'Qté';
$_LANGPDF['PDFff5db4935fb0fbf583796b50f05e25bc'] = 'Une version electronique de ce document est disponible dans votre compte. Pour y accèder connectez vous sur notre site internet en utilisant votre adresse email et mot de passe (Crée lors de votre première commande).		';
$_LANGPDF['PDF59aac4eb50a8249cbc9c12240c6a0a14'] = 'Pour plus d\'informations contactez notre Support:';
$_LANGPDF['PDF2b56b5ec383be252fe778c4c6066b2fb'] = 'Adresse de Paiement & Livraison';
$_LANGPDF['PDF5e5f0a863cd129317037e3def37b4097'] = 'Société:';
$_LANGPDF['PDFd04e2c1b67f3ef0d475409516b812e8b'] = 'SIRET:';
$_LANGPDF['PDF7137a85d9b8d9e6d09f47767d2ca31ee'] = 'APE:';
$_LANGPDF['PDF1a22913fb1b16ada25c2637af9d44013'] = 'Produit / Référence';
$_LANGPDF['PDF197101c4a1b1fc503dcd6ebee127aa10'] = 'Prix Unitaire';
$_LANGPDF['PDF078ac079d154d21533c57bced9fcb10f'] = '(HT)';
$_LANGPDF['PDF104d9898c04874d0fbac36e125fa1369'] = 'Réduction';
$_LANGPDF['PDF03ab340b3f99e03cff9e84314ead38c0'] = 'Qté';
$_LANGPDF['PDF96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF7926243ab60a08b15932021bf108c578'] = 'Total Produits HT';
$_LANGPDF['PDF984a93f9899bf0b0a250ba66f022c630'] = 'Total Produits TTC';
$_LANGPDF['PDF5082245495aa792b3d0874088d2b111b'] = 'Total Produits';
$_LANGPDF['PDF19abe6c02a26dcd93020396df8d0721c'] = 'Total des bons de réduction';
$_LANGPDF['PDFced2da7b2baf942c0ffd4b8e45ec0fad'] = 'Coût d\'emballage';
$_LANGPDF['PDFa5e35abc0c9e2d2784d0ef619b36448b'] = 'Coût de livraison';
$_LANGPDF['PDFb602e0d0c6a72053d0a5be60cb2f8126'] = 'Total Taxes';
$_LANGPDF['PDF4efeae9def7927946cb4929e0d298825'] = 'Restant dû';
$_LANGPDF['PDFe7bbf027179f23c92bec649fa6ae78e4'] = 'L\'article 259B du code général des taxes accorde l\'exonération de TVA.';
$_LANGPDF['PDF6f3455d187a23443796efdcbe044096b'] = 'Pas de taxe';
$_LANGPDF['PDF023f66b09075fa1cc29e74bed9f5ac40'] = 'Détail des taxes';
$_LANGPDF['PDF8fe77c2601e54f1aaef28cfde997bbad'] = 'Taux';
$_LANGPDF['PDF22caf639b05c0fa192e81d58c553c89a'] = 'Total HT';
$_LANGPDF['PDF068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDFea9cf7e47ff33b2be14e6dd07cbcefc6'] = 'Transport';
$_LANGPDF['PDF88be9ea838e21273267409d76af3b284'] = 'Nous avons enregistré votre demande de retour.';
$_LANGPDF['PDFdd0b8feb4eb6c389c284518f5683017c'] = 'Votre paquet doit nous être retourné dans les';
$_LANGPDF['PDFea62a2e28a800c367509773730120a67'] = 'jours après réception de votre commande.';
$_LANGPDF['PDF752ab8bad7c2e2d894ffa7f2b4f59919'] = 'Numéro de retour:';
$_LANGPDF['PDF0d8d58008ef5dd7afce337373ef73993'] = 'Date :';
$_LANGPDF['PDF3796bba38e4bc7dbc3ec97d73be42328'] = 'Si les conditions suivantes ne sont pas respectées, nous nous réservons le droit de refuser votre paquet et/ou votre remboursement:';
$_LANGPDF['PDF9e023503a19456d31f0760015d035e36'] = 'Merci d\'inscrire votre numéro de retour sur votre retour colis:';
$_LANGPDF['PDF67606e3dd25c5effeb991c704b96d19c'] = 'Tous les produits doivent être retournés dans leur emballage d\'origine sans être altéré ou porté.';
$_LANGPDF['PDF34bfda153cbe51eef5d4a88cdd7b616d'] = 'Merci d\'imprimer ces documents et avoir dans votre paquet.';
$_LANGPDF['PDFc7711fbc0d8f010e06a306cc63ef5393'] = 'Le paquet devrait être envoyé à l\'adresse suivante:';
$_LANGPDF['PDF77fd2b4393b379bedd30efcd5df02090'] = 'Remboursement partiel';
$_LANGPDF['PDF66f6e4bbd0a0af1af6b54763871dd280'] = 'Produits commandés :';
$_LANGPDF['PDF63d5049791d9d79d86e9a108b0a999ca'] = 'Référence';
$_LANGPDF['PDFf107f5a9ee4ecea58d0f29ae7959baa8'] = 'Nom';
$_LANGPDF['PDFc8ba77264f6e923f5ee35abf3108ae7c'] = 'Prix unitaire  HT';
$_LANGPDF['PDF3a6a6d37bea2c7567f8599ea88b47930'] = 'Prix HT';
$_LANGPDF['PDF7521172dd37ba56442ea866ac18eb49d'] = 'Avant réduction';
$_LANGPDF['PDF6703aa9936582b4381418f7d523370b4'] = 'Taux de remise';
$_LANGPDF['PDFa61109b693023aed557445989c517982'] = 'Après réduction';
$_LANGPDF['PDF20a34c4e30c5bbe1d3f870ac55f0d831'] = 'Taux TVA';
$_LANGPDF['PDFfa2ce544158555e8f06c69dd9e681832'] = 'Prix TTC ';
$_LANGPDF['PDF716be2c7de31f063369ca297a9928403'] = 'Taxes :';
$_LANGPDF['PDFf4a232c48df10124ee867767a4e7280e'] = 'Base HT';
$_LANGPDF['PDF01a2436b8e3782c1f99e6b26adf901b2'] = 'Montant TVA';
$_LANGPDF['PDF1300f86974cafc2d65eb1f082a26bdf1'] = 'Résumé :';
$_LANGPDF['PDF627be65d466c88030f7afcfdaf6d794f'] = 'Brut (Avant remise)';
$_LANGPDF['PDF6b9e9f2472786ed1e76005bfc37bc8af'] = 'Remise globale';
$_LANGPDF['PDF77c48b105700c87484e3008ca52a8e57'] = 'Net (Après remise)';
$_LANGPDF['PDF699e6bd4690ed3bd5f658052e12aba04'] = 'Montant TVA';
$_LANGPDF['PDF448634536559b1f8aaa975e0aa12b930'] = 'NET A PAYER';

?>

==> prestashop_1.5.0.9.zip: prestashop/themes/default/pdf/lang/fr.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['submitTranslationsPdf'] = 'Enregistrer les modifications';
$_LANGPDF['PDF065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF6c2fbe34c186a6b5725d212ad8cd2432'] = 'Facture';
$_LANGPDF['PDFc7d76074f459eaa296d3eb71efc23eba'] = 'Bon #';
$_LANGPDF['PDFf771e4a4df40bf061607fdb8e3f140dc'] = 'Bon de commande';
$_LANGPDF['PDF3a80d6ec5285dd5d3930db30d04e2b9e'] = 'HR : hors remise';
$_LANGPDF['PDFa58b1c9575ab07c5be819243c96d9c0e'] = 'RC : remise comprise';
$_LANGPDF['PDF2f2f0f119a907c6c67a3c6fcde0193ab'] = 'Addresse de Livraison';
$_LANGPDF['PDF28a59051cd90053f87bacd5f1ffbc0b8'] = 'Adresse de Paiement';
$_LANGPDF['PDFe2f324b87eac820c81e4d4a1105dcddf'] = 'Adresse de Paiement & Livraison';
$_LANGPDF['PDFd8b2145d049378e78bd41e65b31213f0'] = 'Num. commande :';
$_LANGPDF['PDF8a5a12ba783d8cbb761974430d0a4d6a'] = 'Date commande :';
$_LANGPDF['PDFd36a6948b01d3a75ed99858e2bfea939'] = 'Méthode de paiement :';
$_LANGPDF['PDFe40007b408ac5f66d2c2e6c54f787c99'] = 'Aucun paiement';
$_LANGPDF['PDFf6244b08d5e0715572f9d4631b425eae'] = 'Articles à livrer';
$_LANGPDF['PDFdcd320d017d7f3c317bc8b234287bc9f'] = 'Réference';
$_LANGPDF['PDFe36ba4b339b83cbb3c807bd0eb5610bc'] = 'Qté';
$_LANGPDF['PDFff5db4935fb0fbf583796b50f05e25bc'] = 'Une version electronique de ce document est disponible dans votre compte. Pour y accèder connectez vous sur notre site internet en utilisant votre adresse email et mot de passe (Crée lors de votre première commande).		';
$_LANGPDF['PDF59aac4eb50a8249cbc9c12240c6a0a14'] = 'Pour plus d\'informations contactez notre Support:';
$_LANGPDF['PDF2b56b5ec383be252fe778c4c6066b2fb'] = 'Adresse de Paiement & Livraison';
$_LANGPDF['PDF5e5f0a863cd129317037e3def37b4097'] = 'Société:';
$_LANGPDF['PDFd04e2c1b67f3ef0d475409516b812e8b'] = 'SIRET:';
$_LANGPDF['PDF7137a85d9b8d9e6d09f47767d2ca31ee'] = 'APE:';
$_LANGPDF['PDF1a22913fb1b16ada25c2637af9d44013'] = 'Produit / Référence';
$_LANGPDF['PDF197101c4a1b1fc503dcd6ebee127aa10'] = 'Prix Unitaire';
$_LANGPDF['PDF078ac079d154d21533c57bced9fcb10f'] = '(HT)';
$_LANGPDF['PDF104d9898c04874d0fbac36e125fa1369'] = 'Réduction';
$_LANGPDF['PDF03ab340b3f99e03cff9e84314ead38c0'] = 'Qté';
$_LANGPDF['PDF96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF7926243ab60a08b15932021bf108c578'] = 'Total Produits HT';
$_LANGPDF['PDF984a93f9899bf0b0a250ba66f022c630'] = 'Total Produits TTC';
$_LANGPDF['PDF5082245495aa792b3d0874088d2b111b'] = 'Total Produits';
$_LANGPDF['PDF19abe6c02a26dcd93020396df8d0721c'] = 'Total des bons de réduction';
$_LANGPDF['PDFced2da7b2baf942c0ffd4b8e45ec0fad'] = 'Coût d\'emballage';
$_LANGPDF['PDFa5e35abc0c9e2d2784d0ef619b36448b'] = 'Coût de livraison';
$_LANGPDF['PDFb602e0d0c6a72053d0a5be60cb2f8126'] = 'Total Taxes';
$_LANGPDF['PDF4efeae9def7927946cb4929e0d298825'] = 'Restant dû';
$_LANGPDF['PDFe7bbf027179f23c92bec649fa6ae78e4'] = 'L\'article 259B du code général des taxes accorde l\'exonération de TVA.';
$_LANGPDF['PDF6f3455d187a23443796efdcbe044096b'] = 'Pas de taxe';
$_LANGPDF['PDF023f66b09075fa1cc29e74bed9f5ac40'] = 'Détail des taxes';
$_LANGPDF['PDF8fe77c2601e54f1aaef28cfde997bbad'] = 'Taux';
$_LANGPDF['PDF22caf639b05c0fa192e81d58c553c89a'] = 'Total HT';
$_LANGPDF['PDF068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDFea9cf7e47ff33b2be14e6dd07cbcefc6'] = 'Transport';
$_LANGPDF['PDF88be9ea838e21273267409d76af3b284'] = 'Nous avons enregistré votre demande de retour.';
$_LANGPDF['PDFdd0b8feb4eb6c389c284518f5683017c'] = 'Votre paquet doit nous être retourné dans les';
$_LANGPDF['PDFea62a2e28a800c367509773730120a67'] = 'jours après réception de votre commande.';
$_LANGPDF['PDF752ab8bad7c2e2d894ffa7f2b4f59919'] = 'Numéro de retour:';
$_LANGPDF['PDF0d8d58008ef5dd7afce337373ef73993'] = 'Date :';
$_LANGPDF['PDF24488494b2a9126a5ef1dfdaea5913da'] = 'Produits à retourner';
$_LANGPDF['PDF3796bba38e4bc7dbc3ec97d73be42328'] = 'Si les conditions suivantes ne sont pas respectées, nous nous réservons le droit de refuser votre paquet et/ou votre remboursement:';
$_LANGPDF['PDF9e023503a19456d31f0760015d035e36'] = 'Merci d\'inscrire votre numéro de retour sur votre retour colis:';
$_LANGPDF['PDF67606e3dd25c5effeb991c704b96d19c'] = 'Tous les produits doivent être retournés dans leur emballage d\'origine sans être altéré ou porté.';
$_LANGPDF['PDF34bfda153cbe51eef5d4a88cdd7b616d'] = 'Merci d\'imprimer ces documents et avoir dans votre paquet.';
$_LANGPDF['PDFc7711fbc0d8f010e06a306cc63ef5393'] = 'Le paquet devrait être envoyé à l\'adresse suivante:';
$_LANGPDF['PDF77fd2b4393b379bedd30efcd5df02090'] = 'Remboursement partiel';
$_LANGPDF['PDF66f6e4bbd0a0af1af6b54763871dd280'] = 'Produits commandés :';
$_LANGPDF['PDF63d5049791d9d79d86e9a108b0a999ca'] = 'Référence';
$_LANGPDF['PDFf107f5a9ee4ecea58d0f29ae7959baa8'] = 'Nom';
$_LANGPDF['PDFc8ba77264f6e923f5ee35abf3108ae7c'] = 'Prix unitaire  HT';
$_LANGPDF['PDF3a6a6d37bea2c7567f8599ea88b47930'] = 'Prix HT';
$_LANGPDF['PDF7521172dd37ba56442ea866ac18eb49d'] = 'Avant réduction';
$_LANGPDF['PDF6703aa9936582b4381418f7d523370b4'] = 'Taux de remise';
$_LANGPDF['PDFa61109b693023aed557445989c517982'] = 'Après réduction';
$_LANGPDF['PDF20a34c4e30c5bbe1d3f870ac55f0d831'] = 'Taux TVA';
$_LANGPDF['PDFfa2ce544158555e8f06c69dd9e681832'] = 'Prix TTC ';
$_LANGPDF['PDF716be2c7de31f063369ca297a9928403'] = 'Taxes :';
$_LANGPDF['PDFf4a232c48df10124ee867767a4e7280e'] = 'Base HT';
$_LANGPDF['PDF01a2436b8e3782c1f99e6b26adf901b2'] = 'Montant TVA';
$_LANGPDF['PDF1300f86974cafc2d65eb1f082a26bdf1'] = 'Résumé :';
$_LANGPDF['PDF627be65d466c88030f7afcfdaf6d794f'] = 'Brut (Avant remise)';
$_LANGPDF['PDF6b9e9f2472786ed1e76005bfc37bc8af'] = 'Remise globale';
$_LANGPDF['PDF77c48b105700c87484e3008ca52a8e57'] = 'Net (Après remise)';
$_LANGPDF['PDF699e6bd4690ed3bd5f658052e12aba04'] = 'Montant TVA';
$_LANGPDF['PDF448634536559b1f8aaa975e0aa12b930'] = 'NET A PAYER';

?>
